@@ -59,13 +59,19 @@ test_gcc_9() {
 test_arm64_gcc() {
     get_build_args arm64_gcc
     assertArg 'BASE=$(PROJECT)/gcc' 'HOSTARCH=aarch64'\
-        'PACKAGES="gcc-aarch64-linux-gnu g++-aarch64-linux-gnu"'
+        'PACKAGES="gcc g++ gcc-aarch64-linux-gnu g++-aarch64-linux-gnu"'
 }
 
 test_arm64_gcc_8() {
     get_build_args arm64_gcc-8
     assertArg 'BASE=$(PROJECT)/gcc' 'HOSTARCH=aarch64'\
-        'PACKAGES="gcc-8-aarch64-linux-gnu g++-8-aarch64-linux-gnu"'
+        'PACKAGES="gcc-8 g++-8 gcc-8-aarch64-linux-gnu g++-8-aarch64-linux-gnu"'
+}
+
+test_x86_64_gcc() {
+    get_build_args x86_64_gcc
+    assertArg 'BASE=$(PROJECT)/gcc' 'HOSTARCH=x86_64'\
+        'PACKAGES="gcc g++ gcc-x86-64-linux-gnu g++-x86-64-linux-gnu"'
 }
 
 test_clang() {
@@ -73,6 +79,12 @@ test_clang() {
     assertArg 'BASE=$(PROJECT)/base' 'PACKAGES="clang"'
 }
 
+test_arm64_clang() {
+    get_build_args arm64_clang
+    assertArg 'BASE=$(PROJECT)/clang' 'HOSTARCH=aarch64' \
+        'PACKAGES="gcc-aarch64-linux-gnu g++-aarch64-linux-gnu"'
+}
+
 test_clang8() {
     get_build_args clang-8
     assertArg 'BASE=$(PROJECT)/base' 'PACKAGES="clang-8"'
