@@ -173,6 +173,14 @@ def test_kconfig_add_inline_not_set(linux, output_dir):
     assert "CONFIG_FOO is not set\n" in config.read_text()
 
 
+def test_kconfig_add_inline_set_to_no(linux, output_dir):
+    build(
+        linux, targets=["config"], kconfig_add=["CONFIG_FOO=n"], output_dir=output_dir
+    )
+    config = output_dir / "config"
+    assert "CONFIG_FOO=n\n" in config.read_text()
+
+
 def test_kconfig_add_in_tree(linux, output_dir):
     build(
         linux,
@@ -235,6 +243,13 @@ def test_verbose(linux, mocker, Popen):
     assert "--silent" not in args(Popen)
 
 
+def test_quiet(linux, capfd):
+    build(linux, quiet=True)
+    out, err = capfd.readouterr()
+    assert out == ""
+    assert err == ""
+
+
 def test_ctrl_c(linux, mocker, Popen):
     mocker.patch("tuxmake.build.Build.logger")
     process = mocker.MagicMock()
@@ -255,6 +270,26 @@ class TestArchitecture:
         result = build(linux, target_arch="arm64")
         assert "Image.gz" in [str(f.name) for f in result.output_dir.glob("*")]
 
+    def test_arm(self, linux):
+        result = build(linux, target_arch="arm")
+        assert "zImage" in [str(f.name) for f in result.output_dir.glob("*")]
+
+    def test_i386(self, linux):
+        result = build(linux, target_arch="i386")
+        assert "bzImage" in [str(f.name) for f in result.output_dir.glob("*")]
+
+    def test_mips(self, linux):
+        result = build(linux, target_arch="mips")
+        assert "vmlinux.bin.gz" in [str(f.name) for f in result.output_dir.glob("*")]
+
+    def test_riscv(self, linux):
+        result = build(linux, target_arch="riscv")
+        assert "Image.gz" in [str(f.name) for f in result.output_dir.glob("*")]
+
+    def test_arc(self, linux):
+        result = build(linux, target_arch="arc")
+        assert "uImage.gz" in [str(f.name) for f in result.output_dir.glob("*")]
+
     def test_invalid_arch(self):
         with pytest.raises(tuxmake.exceptions.UnsupportedArchitecture):
             Architecture("foobar")
@@ -292,38 +327,40 @@ class TestDebugKernel:
     def test_build_with_debugkernel(self, linux):
         result = build(linux, targets=["config", "debugkernel"])
         artifacts = [str(f.name) for f in result.output_dir.glob("*")]
-        assert "vmlinux" in artifacts
+        assert "vmlinux.xz" in artifacts
+        assert "System.map" in artifacts
 
     def test_build_with_debugkernel_arm64(self, linux):
         result = build(linux, targets=["config", "debugkernel"], target_arch="arm64")
         artifacts = [str(f.name) for f in result.output_dir.glob("*")]
-        assert "vmlinux" in artifacts
+        assert "vmlinux.xz" in artifacts
+        assert "System.map" in artifacts
 
 
 class TestModules:
     def test_modules(self, linux):
         result = build(linux, targets=["config", "kernel", "modules"])
         artifacts = [str(f.name) for f in result.output_dir.glob("*")]
-        assert "modules.tar.gz" in artifacts
+        assert "modules.tar.xz" in artifacts
 
     def test_skip_if_not_configured_for_modules(self, linux):
         result = build(
             linux, targets=["config", "kernel", "modules"], kconfig="tinyconfig"
         )
         artifacts = [str(f.name) for f in result.output_dir.glob("*")]
-        assert "modules.tar.gz" not in artifacts
+        assert "modules.tar.xz" not in artifacts
 
 
 class TestDtbs:
     def test_dtbs(self, linux):
         result = build(linux, targets=["dtbs"], target_arch="arm64")
         artifacts = [str(f.name) for f in result.output_dir.glob("*")]
-        assert "dtbs.tar.gz" in artifacts
+        assert "dtbs.tar.xz" in artifacts
 
     def test_skip_on_arch_with_no_dtbs(self, linux):
         result = build(linux, targets=["dtbs"], target_arch="x86_64")
         artifacts = [str(f.name) for f in result.output_dir.glob("*")]
-        assert "dtbs.tar.gz" not in artifacts
+        assert "dtbs.tar.xz" not in artifacts
 
 
 class TestTargetDependencies:
@@ -378,6 +415,22 @@ class TestCompilerWrappers:
         assert "CC=ccache gcc-10" in args(Popen)
         assert "HOSTCC=ccache gcc-10" in args(Popen)
 
+    def test_ccache_target_arch(self, linux, Popen):
+        b = Build(linux, targets=["config"], target_arch="arm64", wrapper="ccache")
+        b.build(b.targets[0])
+        assert "CC=ccache aarch64-linux-gnu-gcc" in args(Popen)
+
+    def test_ccache_target_arch_and_gcc_v(self, linux, Popen):
+        b = Build(
+            linux,
+            targets=["config"],
+            toolchain="gcc-10",
+            target_arch="arm64",
+            wrapper="ccache",
+        )
+        b.build(b.targets[0])
+        assert "CC=ccache aarch64-linux-gnu-gcc-10" in args(Popen)
+
 
 @pytest.mark.skipif(
     [int(n) for n in pytest.__version__.split(".")] < [3, 10], reason="old pytest"
