@@ -97,11 +97,21 @@ class TestRuntime:
         assert args(builder).runtime == "docker"
 
 
-class TestVerbose:
+class TestVerbosity:
     def test_verbose(self, builder):
         tuxmake("--verbose")
         assert args(builder).verbose
 
+    def test_quiet(self, builder):
+        tuxmake("--quiet")
+        assert args(builder).quiet
+
+    def test_quiet_build(self, capsys):
+        tuxmake("--quiet")
+        out, err = capsys.readouterr()
+        assert out == ""
+        assert err == ""
+
 
 class TestEnvironment:
     def test_environment(self, builder):
@@ -152,3 +162,49 @@ class TestBuildStatus:
         _, err = capsys.readouterr()
         assert "config: PASS" in err
         assert "kernel: FAIL" in err
+
+
+class TestList:
+    def test_list_architectures(self, builder, capsys):
+        tuxmake("--list-architectures")
+        builder.assert_not_called()
+        out, _ = capsys.readouterr()
+        assert "x86_64" in out
+        assert "arm64" in out
+
+    def test_list_toolchains(self, builder, capsys):
+        tuxmake("--list-toolchains")
+        builder.assert_not_called()
+        out, _ = capsys.readouterr()
+        assert "gcc" in out
+        assert "clang" in out
+
+    def test_list_docker_toolchains(self, builder, capsys):
+        tuxmake("--runtime=docker", "--list-toolchains")
+        builder.assert_not_called()
+        out, _ = capsys.readouterr()
+        assert "gcc" in out
+        assert "gcc-10" in out
+        assert "clang" in out
+        assert "clang-10" in out
+
+
+class TestPrintSupportMatrix:
+    def test_print_support_matrix(self, builder, capsys):
+        tuxmake("--print-support-matrix")
+        builder.assert_not_called()
+        out, _ = capsys.readouterr()
+        assert out
+
+    def test_print_support_matrix_docker(self, builder, capsys):
+        tuxmake("--runtime=docker", "--print-support-matrix")
+        builder.assert_not_called()
+        out, _ = capsys.readouterr()
+        assert "yes" in out
+        assert "no" in out
+
+    def test_output_colors_when_requested(self, builder, capsys):
+        tuxmake("--runtime=docker", "--color=always", "--print-support-matrix")
+        builder.assert_not_called()
+        out, _ = capsys.readouterr()
+        assert "\033" in out
