@@ -18,23 +18,22 @@ def build(linux):
 
 
 class TestGetRuntime:
-    def test_null_runtime(self, build):
-        build.docker = False
-        assert isinstance(get_runtime(build, None), NullRuntime)
+    def test_null_runtime(self):
+        assert isinstance(get_runtime(None), NullRuntime)
 
-    def test_docker_runtime(self, build):
-        assert isinstance(get_runtime(build, "docker"), DockerRuntime)
+    def test_docker_runtime(self):
+        assert isinstance(get_runtime("docker"), DockerRuntime)
 
-    def test_invalid_runtime(self, build):
+    def test_invalid_runtime(self):
         with pytest.raises(InvalidRuntimeError):
-            get_runtime(build, "invalid")
+            get_runtime("invalid")
         with pytest.raises(InvalidRuntimeError):
-            get_runtime(build, "xyz")
+            get_runtime("xyz")
 
 
 class TestNullRuntime:
     def test_get_command_line(self, build):
-        assert NullRuntime(build).get_command_line(["date"]) == ["date"]
+        assert NullRuntime().get_command_line(build, ["date"]) == ["date"]
 
 
 @pytest.fixture
@@ -45,62 +44,73 @@ def get_docker_image(mocker):
 class TestDockerRuntime:
     def test_docker_image(self, build, get_docker_image):
         get_docker_image.return_value = "foobarbaz"
-        runtime = DockerRuntime(build)
-        assert runtime.image == "foobarbaz"
+        runtime = DockerRuntime()
+        assert runtime.get_image(build) == "foobarbaz"
 
     def test_override_docker_image(self, build, monkeypatch):
         monkeypatch.setenv("TUXMAKE_DOCKER_IMAGE", "foobar")
-        runtime = DockerRuntime(build)
-        assert runtime.image == "foobar"
+        runtime = DockerRuntime()
+        assert runtime.get_image(build) == "foobar"
 
     def test_prepare(self, build, get_docker_image, mocker):
         get_docker_image.return_value = "myimage"
         check_call = mocker.patch("subprocess.check_call")
-        DockerRuntime(build).prepare()
+        DockerRuntime().prepare(build)
         check_call.assert_called_with(["docker", "pull", "myimage"])
 
     def test_get_command_line(self, build):
-        cmd = DockerRuntime(build).get_command_line(["date"])
+        cmd = DockerRuntime().get_command_line(build, ["date"])
         assert cmd[0:2] == ["docker", "run"]
         assert cmd[-1] == "date"
 
     def test_environment(self, build):
         build.environment = {"FOO": "BAR"}
-        cmd = DockerRuntime(build).get_command_line(["date"])
+        cmd = DockerRuntime().get_command_line(build, ["date"])
         assert "--env=FOO=BAR" in cmd
 
     def test_ccache(self, build, home):
         ccache = Wrapper("ccache")
         orig_ccache_dir = ccache.environment["CCACHE_DIR"]
         build.wrapper = ccache
-        cmd = DockerRuntime(build).get_command_line(["date"])
+        cmd = DockerRuntime().get_command_line(build, ["date"])
         assert "--env=CCACHE_DIR=/ccache-dir" in cmd
         assert f"--volume={orig_ccache_dir}:/ccache-dir" in cmd
 
     def test_sccache_with_path(self, build, home):
         sccache_from_host = Wrapper("/opt/bin/sccache")
         build.wrapper = sccache_from_host
-        cmd = DockerRuntime(build).get_command_line(["date"])
+        cmd = DockerRuntime().get_command_line(build, ["date"])
         assert "--volume=/opt/bin/sccache:/usr/local/bin/sccache" in cmd
 
     def test_TUXMAKE_DOCKER_RUN(self, build, monkeypatch):
         monkeypatch.setenv(
             "TUXMAKE_DOCKER_RUN", "--hostname=foobar --env=FOO='bar baz'"
         )
-        cmd = DockerRuntime(build).get_command_line(["bash"])
+        cmd = DockerRuntime().get_command_line(build, ["bash"])
         assert "--hostname=foobar" in cmd
         assert "--env=FOO=bar baz" in cmd
 
+    def test_bases(self):
+        assert "base-debian" in [t.name for t in DockerRuntime().base_images]
+
+    def test_ci_images(self):
+        assert "ci-python3.8" in [t.name for t in DockerRuntime().ci_images]
+
+    def test_toolchains(self):
+        assert "gcc" in [t.name for t in DockerRuntime().toolchain_images]
+
 
 class TestDockerLocalRuntime:
     def test_prepare_checks_local_image(self, build, get_docker_image, mocker):
         get_docker_image.return_value = "mylocalimage"
         check_call = mocker.patch("subprocess.check_call")
-        runtime = DockerLocalRuntime(build)
+        runtime = DockerLocalRuntime()
 
-        runtime.prepare()
+        runtime.prepare(build)
         check_call.assert_called_with(
-            ["docker", "image", "inspect", mocker.ANY, "mylocalimage"]
+            ["docker", "image", "inspect", "mylocalimage"],
+            stdout=subprocess.DEVNULL,
+            stderr=subprocess.DEVNULL,
         )
 
     def test_prepare_image_not_found(self, build, get_docker_image, mocker):
@@ -112,5 +122,5 @@ class TestDockerLocalRuntime:
             ),
         )
         with pytest.raises(RuntimePreparationFailed) as exc:
-            DockerLocalRuntime(build).prepare()
+            DockerLocalRuntime().prepare(build)
         assert "image foobar not found locally" in str(exc)
