@@ -9,7 +9,7 @@ import shutil
 import subprocess
 import sys
 import time
-from tuxmake.arch import Architecture, Native
+from tuxmake.arch import Architecture, host_arch
 from tuxmake.toolchain import Toolchain, NoExplicitToolchain
 from tuxmake.wrapper import Wrapper, NoWrapper
 from tuxmake.output import get_new_output_dir
@@ -67,6 +67,7 @@ class Build:
         jobs=defaults.jobs,
         runtime=None,
         verbose=False,
+        quiet=False,
     ):
         self.source_tree = source_tree
 
@@ -79,7 +80,7 @@ class Build:
         self.build_dir = self.output_dir / "tmp"
         os.mkdir(self.build_dir)
 
-        self.target_arch = target_arch and Architecture(target_arch) or Native()
+        self.target_arch = target_arch and Architecture(target_arch) or host_arch
         self.toolchain = toolchain and Toolchain(toolchain) or NoExplicitToolchain()
         self.wrapper = wrapper and Wrapper(wrapper) or NoWrapper()
 
@@ -94,9 +95,10 @@ class Build:
 
         self.jobs = jobs
 
-        self.runtime = get_runtime(self, runtime)
+        self.runtime = get_runtime(runtime)
 
         self.verbose = verbose
+        self.quiet = quiet
 
         self.artifacts = ["build.log"]
         self.__logger__ = None
@@ -123,7 +125,7 @@ class Build:
             + " ".join(["tuxmake"] + [shlex.quote(a) for a in sys.argv[1:]])
         )
         self.wrapper.prepare()
-        self.runtime.prepare()
+        self.runtime.prepare(self)
 
     def get_silent(self):
         if self.verbose:
@@ -136,14 +138,17 @@ class Build:
         for c in origcmd:
             cmd += self.expand_cmd_part(c)
 
-        final_cmd = self.runtime.get_command_line(cmd)
+        final_cmd = self.runtime.get_command_line(self, cmd)
         env = dict(os.environ, **self.wrapper.environment, **self.environment)
 
+        logger = self.logger.stdin
         if output:
             stdout = subprocess.PIPE
+            stderr = logger
         else:
             self.log(" ".join([shlex.quote(c) for c in cmd]))
-            stdout = self.logger.stdin
+            stdout = logger
+            stderr = subprocess.STDOUT
 
         process = subprocess.Popen(
             final_cmd,
@@ -151,7 +156,7 @@ class Build:
             env=env,
             stdin=subprocess.DEVNULL,
             stdout=stdout,
-            stderr=subprocess.STDOUT,
+            stderr=stderr,
         )
         try:
             out, _ = process.communicate()
@@ -171,20 +176,27 @@ class Build:
                 + self.make_args
             )
         else:
-            return [
-                part.format(
-                    build_dir=self.build_dir,
-                    target_arch=self.target_arch.name,
-                    toolchain=self.toolchain.name,
-                    kconfig=self.kconfig,
-                )
-            ]
+            return [self.format_cmd_part(part)]
+
+    def format_cmd_part(self, part):
+        return part.format(
+            build_dir=self.build_dir,
+            target_arch=self.target_arch.name,
+            toolchain=self.toolchain.name,
+            kconfig=self.kconfig,
+        )
 
     @property
     def logger(self):
         if not self.__logger__:
+            if self.quiet:
+                stdout = subprocess.DEVNULL
+            else:
+                stdout = sys.stdout
             self.__logger__ = subprocess.Popen(
-                ["tee", str(self.output_dir / "build.log")], stdin=subprocess.PIPE
+                ["tee", str(self.output_dir / "build.log")],
+                stdin=subprocess.PIPE,
+                stdout=stdout,
             )
         return self.__logger__
 
@@ -310,10 +322,10 @@ class Build:
         for target in self.targets:
             self.copy_artifacts(target)
 
-        self.terminate()
-
         self.extract_metadata()
 
+        self.terminate()
+
         self.cleanup()
 
 
