@@ -3,6 +3,7 @@ import sys
 from tuxmake import __version__
 from tuxmake.build import build, supported, defaults
 from tuxmake.exceptions import TuxMakeException
+from tuxmake.runtime import get_runtime
 
 
 def key_value(s):
@@ -97,23 +98,104 @@ def main(*argv):
         action="store_true",
         help="Do a verbose build (default: silent build)",
     )
+    buildenv.add_argument(
+        "-q",
+        "--quiet",
+        action="store_true",
+        help="Quiet build: only errors messages, if any (default: no)",
+    )
 
     info = parser.add_argument_group("Informational options")
     info.add_argument("-h", "--help", action="help", help="Show program help")
     info.add_argument(
         "-V", "--version", action="version", version=f"%(prog)s {__version__}"
     )
+    info.add_argument(
+        "--list-architectures",
+        action="store_true",
+        help="List supported architectures and exit",
+    )
+    info.add_argument(
+        "--list-toolchains",
+        action="store_true",
+        help="List supported toolchains and exit. Combine with --runtime to list toolchains supported by that particular runtime.",
+    )
+    info.add_argument(
+        "--print-support-matrix",
+        action="store_true",
+        help="Print support matrix (architectures x toolchains). Combine with --runtime to list support matrix for that particular runtime.",
+    )
+    info.add_argument(
+        "-c",
+        "--color",
+        type=str,
+        default="auto",
+        choices=["always", "never", "auto"],
+        help="Control use of colored output. `always` and `never` do what you expect; `auto` (the default) outputs colors when stdou is a tty",
+    )
 
     options = parser.parse_args(argv)
+
+    if options.color == "always" or (options.color == "auto" and sys.stdout.isatty()):
+
+        def format_yes_no(b, length):
+            if b:
+                return "\033[32myes\033[m" + " " * (length - 3)
+            else:
+                return "\033[31mno\033[m" + " " * (length - 2)
+
+    else:
+
+        def format_yes_no(b, length):
+            return f"%-{length}s" % (b and "yes" or "no")
+
+    if options.list_architectures:
+        for arch in sorted(supported.architectures):
+            print(arch)
+        return
+    elif options.list_toolchains:
+        runtime = get_runtime(options.runtime)
+        for toolchain in sorted(runtime.toolchains):
+            print(toolchain)
+        return
+    elif options.print_support_matrix:
+        runtime = get_runtime(options.runtime)
+        architectures = sorted(supported.architectures)
+        toolchains = sorted(runtime.toolchains)
+        matrix = {}
+        for a in architectures:
+            matrix[a] = {}
+            for t in toolchains:
+                matrix[a][t] = runtime.is_supported(a, t)
+        length_a = max([len(a) for a in architectures])
+        length_t = max([len(t) for t in toolchains])
+        arch_format = f"%-{length_a}s"
+        toolchain_format = f"%-{length_t}s"
+        print(" ".join([" " * length_t] + [arch_format % a for a in architectures]))
+        for t in toolchains:
+            print(
+                " ".join(
+                    [toolchain_format % t]
+                    + [format_yes_no(matrix[a][t], length_a) for a in architectures]
+                )
+            )
+
+        return
+
     if options.environment:
         options.environment = dict(options.environment)
 
-    build_args = {k: v for k, v in options.__dict__.items() if v}
+    if options.quiet:
+        err = open("/dev/null", "w")
+    else:
+        err = sys.stderr
+
+    build_args = {k: v for k, v in options.__dict__.items() if v and k != "color"}
     try:
         result = build(**build_args)
         for target, info in result.status.items():
-            print(f"I: {target}: {info.status} in {info.duration}", file=sys.stderr)
-        print(f"I: build output in {result.output_dir}", file=sys.stderr)
+            print(f"I: {target}: {info.status} in {info.duration}", file=err)
+        print(f"I: build output in {result.output_dir}", file=err)
         if result.failed:
             sys.exit(2)
     except TuxMakeException as e:
