@@ -16,8 +16,9 @@ class Toolchain(ConfigurableObject):
         self.docker_image = self.config["docker"]["image"]
 
     def expand_makevars(self, arch):
+        archvars = {"CROSS_COMPILE": "", **arch.makevars}
         return {
-            k: v.format(toolchain=self.name, **arch.makevars)
+            k: v.format(toolchain=self.name, **archvars)
             for k, v in self.makevars.items()
         }
 
@@ -26,8 +27,14 @@ class Toolchain(ConfigurableObject):
             "{arch}", arch.name
         )
 
+    def compiler(self, arch):
+        return self.expand_makevars(arch).get("CC")
+
 
 class NoExplicitToolchain(Toolchain):
     def __init__(self):
         super().__init__("gcc")
         self.makevars = {}
+
+    def compiler(self, arch):
+        return arch.makevars.get("CROSS_COMPILE", "") + self.name
